@@ -11,7 +11,7 @@ use Ogg::Vorbis::Header;
 require Inline;
 Inline->init;
 
-our $VERSION = sprintf "%d.%02d", '$Revision: 1.3 $ ' =~ /(\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%02d", '$Revision: 1.4 $ ' =~ /(\d+)\.(\d+)/;
 
 my %data = (artist => 'artist',
             title  => 'title',
@@ -35,7 +35,16 @@ sub AUTOLOAD {
 
   my ($pkg, $sub) = $AUTOLOAD =~ /(.*)::(\w+)/;
 
-  die "Invalid attribute $sub" unless $data{$sub};
+  croak "Invalid attribute '$sub'" unless $data{$sub};
+
+  if ($_[1]) {
+    if (grep { $data{$sub} } $_[0]->{obj}->comment_tags) {
+      $_[0]->{obj}->edit_comment($data{$sub}, $_[1]);
+    } else {
+      $_[0]->{obj}->add_comments($data{$sub}, $_[1]);
+    }
+    $_[0]->{obj}->write_vorbis;
+  }
 
   return ($_[0]->{obj}->comment($data{$sub}))[0];
 }
